summaryrefslogtreecommitdiff
path: root/dist
diff options
context:
space:
mode:
authorPeter John Acklam <pjacklam@online.no>2010-11-29 16:00:07 +0100
committerFlorian Ragwitz <rafl@debian.org>2010-11-30 13:39:30 +0100
commitf603091d864eb38dabe995c559f17edd4ea9e2d6 (patch)
treea108418662d27482ce36bd7aeba8e4ed9e2dd803 /dist
parentf6ee7b17ee667bcbf2498da72f68d82fe533b6d6 (diff)
downloadperl-f603091d864eb38dabe995c559f17edd4ea9e2d6.tar.gz
Spelling: reminder -> remainder
Diffstat (limited to 'dist')
-rw-r--r--dist/Math-BigInt/lib/Math/BigFloat.pm8
-rw-r--r--dist/Math-BigInt/lib/Math/BigInt.pm2
-rw-r--r--dist/Math-BigInt/t/bigfltpm.inc2
-rw-r--r--dist/Math-BigInt/t/bigintpm.inc4
-rw-r--r--dist/Math-BigInt/t/mbimbf.inc2
-rw-r--r--dist/Math-BigInt/t/upgrade.inc4
6 files changed, 11 insertions, 11 deletions
diff --git a/dist/Math-BigInt/lib/Math/BigInt.pm b/dist/Math-BigInt/lib/Math/BigInt.pm
index 48144223da..bd61d32edd 100644
--- a/dist/Math-BigInt/lib/Math/BigInt.pm
+++ b/dist/Math-BigInt/lib/Math/BigInt.pm
@@ -1653,7 +1653,7 @@ sub _div_inf
if (($x->is_nan() || $y->is_nan()) ||
($x->is_zero() && $y->is_zero()));
- # +-inf / +-inf == NaN, reminder also NaN
+ # +-inf / +-inf == NaN, remainder also NaN
if (($x->{sign} =~ /^[+-]inf$/) && ($y->{sign} =~ /^[+-]inf$/))
{
return wantarray ? ($x->bnan(),$self->bnan()) : $x->bnan();
diff --git a/dist/Math-BigInt/t/bigfltpm.inc b/dist/Math-BigInt/t/bigfltpm.inc
index a27c754a4d..bb5384bc9f 100644
--- a/dist/Math-BigInt/t/bigfltpm.inc
+++ b/dist/Math-BigInt/t/bigfltpm.inc
@@ -1507,7 +1507,7 @@ inf:inf:NaN
inf:-inf:NaN
8:0:8
inf:0:inf
-# exceptions to reminder rule
+# exceptions to remainder rule
-inf:0:-inf
-8:0:-8
0:0:NaN
diff --git a/dist/Math-BigInt/t/bigintpm.inc b/dist/Math-BigInt/t/bigintpm.inc
index 2acaba05e4..e8460041a6 100644
--- a/dist/Math-BigInt/t/bigintpm.inc
+++ b/dist/Math-BigInt/t/bigintpm.inc
@@ -1541,7 +1541,7 @@ inf:inf:NaN,NaN
inf:-inf:NaN,NaN
8:0:inf,8
inf:0:inf,inf
-# exceptions to reminder rule
+# exceptions to remainder rule
-8:0:-inf,-8
-inf:0:-inf,-inf
0:0:NaN,NaN
@@ -1760,7 +1760,7 @@ inf:inf:NaN
inf:-inf:NaN
8:0:8
inf:0:inf
-# exceptions to reminder rule
+# exceptions to remainder rule
-inf:0:-inf
-8:0:-8
0:0:NaN
diff --git a/dist/Math-BigInt/t/mbimbf.inc b/dist/Math-BigInt/t/mbimbf.inc
index 1c79a0d896..50e0ebc7df 100644
--- a/dist/Math-BigInt/t/mbimbf.inc
+++ b/dist/Math-BigInt/t/mbimbf.inc
@@ -584,7 +584,7 @@ is ($x,'12350'); is ($x->{_a},4); is ($x->{_p}, undef);
$x = $mbf->new(100) / 3;
is ($x->{_a}, undef); is ($x->{_p}, undef);
-# result & reminder
+# result & remainder
$x = $mbf->new(100) / 3; ($x,$y) = $x->bdiv(3);
is ($x->{_a}, undef); is ($x->{_p}, undef);
is ($y->{_a}, undef); is ($y->{_p}, undef);
diff --git a/dist/Math-BigInt/t/upgrade.inc b/dist/Math-BigInt/t/upgrade.inc
index e623b731a2..5c8d11a4a8 100644
--- a/dist/Math-BigInt/t/upgrade.inc
+++ b/dist/Math-BigInt/t/upgrade.inc
@@ -862,7 +862,7 @@ inf:inf:NaN,NaN
inf:-inf:NaN,NaN
8:0:inf,8
inf:0:inf,inf
-# exceptions to reminder rule
+# exceptions to remainder rule
-8:0:-inf,-8
-inf:0:-inf,-inf
0:0:NaN,NaN
@@ -965,7 +965,7 @@ inf:inf:NaN
inf:-inf:NaN
8:0:8
inf:0:inf
-# exceptions to reminder rule
+# exceptions to remainder rule
-inf:0:-inf
-8:0:-8
0:0:NaN
diff --git a/dist/Math-BigInt/lib/Math/BigFloat.pm b/dist/Math-BigInt/lib/Math/BigFloat.pm
index ffaf628c82..f2968a2ea3 100644
--- a/dist/Math-BigInt/lib/Math/BigFloat.pm
+++ b/dist/Math-BigInt/lib/Math/BigFloat.pm
@@ -1759,7 +1759,7 @@ sub bdiv
$y->{sign} =~ tr/+-/-+/;
# continue with normal div code:
# make copy of $x in case of list context for later reminder calculation
if (wantarray && $y_not_one)
{
$rem = $x->copy();
@@ -1821,7 +1821,7 @@ sub bdiv
sub bmod
{
# (dividend: BFLOAT or num_str, divisor: BFLOAT or num_str) return reminder
# set up parameters
my ($self,$x,$y,$a,$p,$r) = (ref($_[0]),@_);
@@ -3372,7 +3372,7 @@ sub brsft
# negative amount?
return $x->blsft($y->copy()->babs(),$n) if $y->{sign} =~ /^-/;
# the following call to bdiv() will return either quo or (quo,reminder):
$x->bdiv($n->bpow($y),$a,$p,$r,$y);
}
@@ -4287,7 +4287,7 @@ The following will probably not print what you expect:
print $c->bdiv(123.456),"\n";
-It prints both quotient and reminder since print works in list context. Also,
+It prints both quotient and remainder since print works in list context. Also,
bdiv() will modify $c, so be careful. You probably want to use
print $c / 123.456,"\n";
@@ -1759,7 +1759,7 @@ sub bdiv
$y->{sign} =~ tr/+-/-+/;
# continue with normal div code:
- # make copy of $x in case of list context for later reminder calculation
+ # make copy of $x in case of list context for later remainder calculation
if (wantarray && $y_not_one)
{
@@ -1821,7 +1821,7 @@ sub bdiv
sub bmod
{
- # (dividend: BFLOAT or num_str, divisor: BFLOAT or num_str) return reminder
+ # (dividend: BFLOAT or num_str, divisor: BFLOAT or num_str) return remainder
# set up parameters
my ($self,$x,$y,$a,$p,$r) = (ref($_[0]),@_);
@@ -3372,7 +3372,7 @@ sub brsft
# negative amount?
return $x->blsft($y->copy()->babs(),$n) if $y->{sign} =~ /^-/;
- # the following call to bdiv() will return either quo or (quo,reminder):
+ # the following call to bdiv() will return either quo or (quo,remainder):
$x->bdiv($n->bpow($y),$a,$p,$r,$y);
}